"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QPlainTextEdit(QAbstractScrollArea):
    """
    https://doc.qt.io/qt-6/qplaintextedit.html

    **Detailed Description**

    **Introduction and Concepts**

    QPlainTextEdit is an advanced viewer/editor supporting plain text. It is
    optimized to handle large documents and to respond quickly to user input.

    QPlainText uses very much the same technology and concepts as **QTextEdit**
    , but is optimized for plain text handling.

    QPlainTextEdit works on paragraphs and characters. A paragraph is a
    formatted string which is word-wrapped to fit into the width of the widget.
    By default when reading plain text, one newline signifies a paragraph. A
    document consists of zero or more paragraphs. Paragraphs are separated by
    hard line breaks. Each character within a paragraph has its own attributes,
    for example, font and color.

    The shape of the mouse cursor on a QPlainTextEdit is **Qt::IBeamCursor**  by
    default. It can be changed through the **viewport** ()'s cursor property.

    **Using QPlainTextEdit as a Display Widget**

    The text is set or replaced using **setPlainText** () which deletes the
    existing text and replaces it with the text passed to **setPlainText** ().

    Text can be inserted using the **QTextCursor**  class or using the
    convenience functions **insertPlainText** (), **appendPlainText** () or
    **paste** ().

    By default, the text edit wraps words at whitespace to fit within the text
    edit widget. The **setLineWrapMode** () function is used to specify the kind
    of line wrap you want, **WidgetWidth**  or **NoWrap**  if you don't want any
    wrapping. If you use word wrap to the widget's width **WidgetWidth** , you
    can specify whether to break on whitespace or anywhere with
    **setWordWrapMode** ().

    The **find** () function can be used to find and select a given string
    within the text.

    If you want to limit the total number of paragraphs in a QPlainTextEdit, as
    it is for example useful in a log viewer, then you can use the
    **maximumBlockCount**  property. The combination of **setMaximumBlockCount**
    () and **appendPlainText** () turns QPlainTextEdit into an efficient viewer
    for log text. The scrolling can be reduced with the **centerOnScroll** ()
    property, making the log viewer even faster. Text can be formatted in a
    limited way, either using a syntax highlighter (see below), or by appending
    html-formatted text with **appendHtml** (). While QPlainTextEdit does not
    support complex rich text rendering with tables and floats, it does support
    limited paragraph-based formatting that you may need in a log viewer.

    **Read-only Key Bindings**

    When QPlainTextEdit is used read-only the key bindings are limited to
    navigation, and text may only be selected with the mouse:

    KeypressesAction
    **Qt::UpArrow** Moves one line up.
    **Qt::DownArrow**
    Moves one line down.
    **Qt::LeftArrow** Moves one character to the left.
    **Qt::RightArrow** Moves one character to the right.
    PageUpMoves one
    (viewport) page up.
    PageDownMoves one (viewport) page down.
    HomeMoves to
    the beginning of the text.
    EndMoves to the end of the text.
    Alt+WheelScrolls the page horizontally (the Wheel is the mouse wheel).
    Ctrl+WheelZooms the text.
    Ctrl+ASelects all text.

    **Using QPlainTextEdit as an Editor**

    All the information about using QPlainTextEdit as a display widget also
    applies here.

    Selection of text is handled by the **QTextCursor**  class, which provides
    functionality for creating selections, retrieving the text contents or
    deleting selections. You can retrieve the object that corresponds with the
    user-visible cursor using the **textCursor** () method. If you want to set a
    selection in QPlainTextEdit just create one on a **QTextCursor**  object and
    then make that cursor the visible cursor using **setCursor** (). The
    selection can be copied to the clipboard with **copy** (), or cut to the
    clipboard with **cut** (). The entire text can be selected using
    **selectAll** ().

    QPlainTextEdit holds a **QTextDocument**  object which can be retrieved
    using the **document** () method. You can also set your own document object
    using **setDocument** (). **QTextDocument**  emits a **textChanged** ()
    signal if the text changes and it also provides a isModified() function
    which will return true if the text has been modified since it was either
    loaded or since the last call to setModified with false as argument. In
    addition it provides methods for undo and redo.

    **Syntax Highlighting**

    Just like **QTextEdit** , QPlainTextEdit works together with
    **QSyntaxHighlighter** .

    **Editing Key Bindings**

    The list of key bindings which are implemented for editing:

    KeypressesAction
    BackspaceDeletes the character to the left of the cursor.
    DeleteDeletes the character to the right of the cursor.
    Ctrl+CCopy the
    selected text to the clipboard.
    Ctrl+InsertCopy the selected text to the
    clipboard.
    Ctrl+KDeletes to the end of the line.
    Ctrl+VPastes the
    clipboard text into text edit.
    Shift+InsertPastes the clipboard text into
    text edit.
    Ctrl+XDeletes the selected text and copies it to the clipboard.
    Shift+DeleteDeletes the selected text and copies it to the clipboard.
    Ctrl+ZUndoes the last operation.
    Ctrl+YRedoes the last operation.
    LeftArrowMoves the cursor one character to the left.
    Ctrl+LeftArrowMoves
    the cursor one word to the left.
    RightArrowMoves the cursor one character
    to the right.
    Ctrl+RightArrowMoves the cursor one word to the right.
    UpArrowMoves the cursor one line up.
    Ctrl+UpArrowMoves the cursor one word
    up.
    DownArrowMoves the cursor one line down.
    Ctrl+Down ArrowMoves the
    cursor one word down.
    PageUpMoves the cursor one page up.
    PageDownMoves
    the cursor one page down.
    HomeMoves the cursor to the beginning of the
    line.
    Ctrl+HomeMoves the cursor to the beginning of the text.
    EndMoves
    the cursor to the end of the line.
    Ctrl+EndMoves the cursor to the end of
    the text.
    Alt+WheelScrolls the page horizontally (the Wheel is the mouse
    wheel).
    Ctrl+WheelZooms the text.

    To select (mark) text hold down the Shift key whilst pressing one of the
    movement keystrokes, for example, **Shift+Right Arrow** will select the
    character to the right, and **Shift+Ctrl+Right Arrow** will select the word
    to the right, etc.

    **Differences to QTextEdit**

    QPlainTextEdit is a thin class, implemented by using most of the technology
    that is behind **QTextEdit**  and **QTextDocument** . Its performance
    benefits over **QTextEdit**  stem mostly from using a different and
    simplified text layout called **QPlainTextDocumentLayout**  on the text
    document (see **QTextDocument::setDocumentLayout** ()). The plain text
    document layout does not support tables nor embedded frames, and **replaces
    a pixel-exact height calculation with a line-by-line respectively paragraph-
    by-paragraph scrolling approach**. This makes it possible to handle
    significantly larger documents, and still resize the editor with line wrap
    enabled in real time. It also makes for a fast log viewer (see
    **setMaximumBlockCount** ()).

    **See also** **QTextDocument** , **QTextCursor** , **Qt Widgets -
    Application Example** , **Code Editor Example** , **Syntax Highlighter
    Example** , and **Rich Text Processing** .
    """

    class LineWrapMode(enum.Enum):
        NoWrap: QPlainTextEdit = ...
        WidgetWidth: QPlainTextEdit = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#QPlainTextEdit

        **QPlainTextEdit::QPlainTextEdit(QWidget * parent = nullptr)**

        Constructs an empty QPlainTextEdit with parent **parent**.
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#QPlainTextEdit-1

        **QPlainTextEdit::QPlainTextEdit(const QString & text , QWidget * parent
        = nullptr)**

        Constructs a QPlainTextEdit with parent **parent**. The text edit will
        display the plain text **text**.
        """
        ...

    def setTabStopDistance(self, distance: float) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#tabStopDistance-prop

        **[since 5.10] tabStopDistance : qreal**

        This property holds the tab stop distance in pixels

        By default, this property contains a value of 80 pixels.

        Do not set a value less than the **horizontalAdvance** () of the
        **QChar::VisualTabCharacter**  character, otherwise the tab-character
        will be drawn incompletely.

        This property was introduced in Qt 5.10.

        **Access functions:**

        qreal **tabStopDistance** () const
        void **setTabStopDistance** (qreal
        **distance** )

        **See also** **QTextOption::ShowTabsAndSpaces**  and
        **QTextDocument::defaultTextOption** .
        """
        ...

    def tabStopDistance(self) -> float:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#tabStopDistance-prop

        **[since 5.10] tabStopDistance : qreal**

        This property holds the tab stop distance in pixels

        By default, this property contains a value of 80 pixels.

        Do not set a value less than the **horizontalAdvance** () of the
        **QChar::VisualTabCharacter**  character, otherwise the tab-character
        will be drawn incompletely.

        This property was introduced in Qt 5.10.

        **Access functions:**

        qreal **tabStopDistance** () const
        void **setTabStopDistance** (qreal
        **distance** )

        **See also** **QTextOption::ShowTabsAndSpaces**  and
        **QTextDocument::defaultTextOption** .
        """
        ...

    def placeholderText(self) -> str:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#placeholderText-prop

        **[since 5.3] placeholderText : QString**

        This property holds the editor placeholder text

        Setting this property makes the editor display a grayed-out placeholder
        text as long as the **document** () is empty.

        By default, this property contains an empty string.

        This property was introduced in Qt 5.3.

        **Access functions:**

        QString **placeholderText** () const
        void **setPlaceholderText**
        (const QString & **placeholderText** )

        **See also** **document** ().
        """
        ...

    def setPlaceholderText(self, placeholderText: str) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#placeholderText-prop

        **[since 5.3] placeholderText : QString**

        This property holds the editor placeholder text

        Setting this property makes the editor display a grayed-out placeholder
        text as long as the **document** () is empty.

        By default, this property contains an empty string.

        This property was introduced in Qt 5.3.

        **Access functions:**

        QString **placeholderText** () const
        void **setPlaceholderText**
        (const QString & **placeholderText** )

        **See also** **document** ().
        """
        ...

    def zoomOut(self, range: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#zoomOut

        **[slot] void QPlainTextEdit::zoomOut(int range = 1)**

        Zooms out on the text by making the base font size **range** points
        smaller and recalculating all font sizes to be the new size. This does
        not change the size of any images.

        **See also** **zoomIn** ().
        """
        ...

    def zoomIn(self, range: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#zoomIn

        **[slot] void QPlainTextEdit::zoomIn(int range = 1)**

        Zooms in on the text by making the base font size **range** points
        larger and recalculating all font sizes to be the new size. This does
        not change the size of any images.

        **See also** **zoomOut** ().
        """
        ...

    def anchorAt(self, pos: QtCore.QPoint) -> str:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#anchorAt

        **QString QPlainTextEdit::anchorAt(const QPoint & pos ) const**

        Returns the reference of the anchor at position **pos** , or an empty
        string if no anchor exists at that point.
        """
        ...

    def getPaintContext(self) -> QtGui.QAbstractTextDocumentLayout.PaintContext:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#getPaintContext

        **[protected] QAbstractTextDocumentLayout::PaintContext
        QPlainTextEdit::getPaintContext() const**

        Returns the paint context for the **viewport** (), useful only when
        reimplementing **paintEvent** ().
        """
        ...

    def blockBoundingGeometry(self, block: QtGui.QTextBlock) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#blockBoundingGeometry

        **[protected] QRectF QPlainTextEdit::blockBoundingGeometry(const
        QTextBlock & block ) const**

        Returns the bounding rectangle of the text **block** in content
        coordinates. Translate the rectangle with the **contentOffset** () to
        get visual coordinates on the viewport.

        **See also** **firstVisibleBlock** () and **blockBoundingRect** ().
        """
        ...

    def blockBoundingRect(self, block: QtGui.QTextBlock) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#blockBoundingRect

        **[protected] QRectF QPlainTextEdit::blockBoundingRect(const QTextBlock
        & block ) const**

        Returns the bounding rectangle of the text **block** in the block's own
        coordinates.

        **See also** **blockBoundingGeometry** ().
        """
        ...

    def contentOffset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#contentOffset

        **[protected] QPointF QPlainTextEdit::contentOffset() const**

        Returns the content's origin in viewport coordinates.

        The origin of the content of a plain text edit is always the top left
        corner of the first visible text block. The content offset is different
        from (0,0) when the text has been scrolled horizontally, or when the
        first visible block has been scrolled partially off the screen, i.e. the
        visible text does not start with the first line of the first visible
        block, or when the first visible block is the very first block and the
        editor displays a margin.

        **See also** **firstVisibleBlock** (), **horizontalScrollBar** (), and
        **verticalScrollBar** ().
        """
        ...

    def firstVisibleBlock(self) -> QtGui.QTextBlock:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#firstVisibleBlock

        **[protected] QTextBlock QPlainTextEdit::firstVisibleBlock() const**

        Returns the first visible block.

        **See also** **blockBoundingRect** ().
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#scrollContentsBy

        **[override virtual protected] void QPlainTextEdit::scrollContentsBy(int
        dx , int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).
        """
        ...

    def insertFromMimeData(self, source: QtCore.QMimeData) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#insertFromMimeData

        **[virtual protected] void QPlainTextEdit::insertFromMimeData(const
        QMimeData * source )**

        This function inserts the contents of the MIME data object, specified by
        **source** , into the text edit at the current cursor position. It is
        called whenever text is inserted as the result of a clipboard paste
        operation, or when the text edit accepts data from a drag and drop
        operation.
        """
        ...

    def canInsertFromMimeData(self, source: QtCore.QMimeData) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#canInsertFromMimeData

        **[virtual protected] bool QPlainTextEdit::canInsertFromMimeData(const
        QMimeData * source ) const**

        This function returns `true` if the contents of the MIME data object,
        specified by **source** , can be decoded and inserted into the document.
        It is called for example when during a drag operation the mouse enters
        this widget and it is necessary to determine whether it is possible to
        accept the drag.
        """
        ...

    def createMimeDataFromSelection(self) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#createMimeDataFromSelection

        **[virtual protected] QMimeData
        *QPlainTextEdit::createMimeDataFromSelection() const**

        This function returns a new MIME data object to represent the contents
        of the text edit's current selection. It is called when the selection
        needs to be encapsulated into a new **QMimeData**  object; for example,
        when a drag and drop operation is started, or when data is copied to the
        clipboard.

        If you reimplement this function, note that the ownership of the
        returned **QMimeData**  object is passed to the caller. The selection
        can be retrieved by using the **textCursor** () function.
        """
        ...

    @typing.overload
    def inputMethodQuery(self, property: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#inputMethodQuery

        **[override virtual] QVariant
        QPlainTextEdit::inputMethodQuery(Qt::InputMethodQuery property ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    @typing.overload
    def inputMethodQuery(
        self, query: QtCore.Qt.InputMethodQuery, argument: typing.Any
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#inputMethodQuery

        **[override virtual] QVariant
        QPlainTextEdit::inputMethodQuery(Qt::InputMethodQuery property ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    def inputMethodEvent(self, a0: QtGui.QInputMethodEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#inputMethodEvent

        **[override virtual protected] void
        QPlainTextEdit::inputMethodEvent(QInputMethodEvent * e )**

        Reimplements: **QWidget::inputMethodEvent** (QInputMethodEvent *event).
        """
        ...

    def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#wheelEvent

        **[override virtual protected] void
        QPlainTextEdit::wheelEvent(QWheelEvent * e )**

        Reimplements: **QAbstractScrollArea::wheelEvent** (QWheelEvent *e).
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#changeEvent

        **[override virtual protected] void QPlainTextEdit::changeEvent(QEvent *
        e )**

        Reimplements: **QFrame::changeEvent** (QEvent *ev).
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#showEvent

        **[override virtual protected] void QPlainTextEdit::showEvent(QShowEvent
        *)**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def focusOutEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#focusOutEvent

        **[override virtual protected] void
        QPlainTextEdit::focusOutEvent(QFocusEvent * e )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#focusInEvent

        **[override virtual protected] void
        QPlainTextEdit::focusInEvent(QFocusEvent * e )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def dropEvent(self, e: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#dropEvent

        **[override virtual protected] void QPlainTextEdit::dropEvent(QDropEvent
        * e )**

        Reimplements: **QAbstractScrollArea::dropEvent** (QDropEvent *event).
        """
        ...

    def dragMoveEvent(self, e: QtGui.QDragMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#dragMoveEvent

        **[override virtual protected] void
        QPlainTextEdit::dragMoveEvent(QDragMoveEvent * e )**

        Reimplements: **QAbstractScrollArea::dragMoveEvent** (QDragMoveEvent
        *event).
        """
        ...

    def dragLeaveEvent(self, e: QtGui.QDragLeaveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#dragLeaveEvent

        **[override virtual protected] void
        QPlainTextEdit::dragLeaveEvent(QDragLeaveEvent * e )**

        Reimplements: **QAbstractScrollArea::dragLeaveEvent** (QDragLeaveEvent
        *event).
        """
        ...

    def dragEnterEvent(self, e: QtGui.QDragEnterEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#dragEnterEvent

        **[override virtual protected] void
        QPlainTextEdit::dragEnterEvent(QDragEnterEvent * e )**

        Reimplements: **QAbstractScrollArea::dragEnterEvent** (QDragEnterEvent
        *event).
        """
        ...

    def contextMenuEvent(self, e: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#contextMenuEvent

        **[override virtual protected] void
        QPlainTextEdit::contextMenuEvent(QContextMenuEvent * event )**

        Reimplements: **QAbstractScrollArea::contextMenuEvent**
        (QContextMenuEvent *e).

        Shows the standard context menu created with
        **createStandardContextMenu** ().

        If you do not want the text edit to have a context menu, you can set its
        **contextMenuPolicy**  to **Qt::NoContextMenu** . If you want to
        customize the context menu, reimplement this function. If you want to
        extend the standard context menu, reimplement this function, call
        **createStandardContextMenu** () and extend the menu returned.

        Information about the event is passed in the **event** object.

        void MyQPlainTextEdit::contextMenuEvent(**QContextMenuEvent**  *event)
        {
                **QMenu**  *menu = createStandardContextMenu();
        menu->addAction(tr("My Menu Item"));
                //...
        menu->exec(event->globalPos());
                delete menu;
            }
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#focusNextPrevChild

        **[override virtual protected] bool
        QPlainTextEdit::focusNextPrevChild(bool next )**

        Reimplements: **QWidget::focusNextPrevChild** (bool next).
        """
        ...

    def mouseDoubleClickEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QPlainTextEdit::mouseDoubleClickEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mouseDoubleClickEvent**
        (QMouseEvent *e).
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#mouseReleaseEvent

        **[override virtual protected] void
        QPlainTextEdit::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mouseReleaseEvent** (QMouseEvent
        *e).
        """
        ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#mouseMoveEvent

        **[override virtual protected] void
        QPlainTextEdit::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mouseMoveEvent** (QMouseEvent *e).
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#mousePressEvent

        **[override virtual protected] void
        QPlainTextEdit::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mousePressEvent** (QMouseEvent *e).
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#paintEvent

        **[override virtual protected] void
        QPlainTextEdit::paintEvent(QPaintEvent * e )**

        Reimplements: **QAbstractScrollArea::paintEvent** (QPaintEvent *event).
        """
        ...

    def resizeEvent(self, e: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#resizeEvent

        **[override virtual protected] void
        QPlainTextEdit::resizeEvent(QResizeEvent * e )**

        Reimplements: **QAbstractScrollArea::resizeEvent** (QResizeEvent
        *event).
        """
        ...

    def keyReleaseEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#keyReleaseEvent

        **[override virtual protected] void
        QPlainTextEdit::keyReleaseEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#keyPressEvent

        **[override virtual protected] void
        QPlainTextEdit::keyPressEvent(QKeyEvent * e )**

        Reimplements: **QAbstractScrollArea::keyPressEvent** (QKeyEvent *e).
        """
        ...

    def timerEvent(self, e: QtCore.QTimerEvent) -> None:
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        ...

    def centerCursor(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#centerCursor

        **[slot] void QPlainTextEdit::centerCursor()**

        Scrolls the document in order to center the cursor vertically.

        **See also** **ensureCursorVisible** () and **centerOnScroll** .
        """
        ...

    def appendHtml(self, html: str) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#appendHtml

        **[slot] void QPlainTextEdit::appendHtml(const QString & html )**

        Appends a new paragraph with **html** to the end of the text edit.

        **appendPlainText** ()
        """
        ...

    def appendPlainText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#appendPlainText

        **[slot] void QPlainTextEdit::appendPlainText(const QString & text )**

        Appends a new paragraph with **text** to the end of the text edit.

        **See also** **appendHtml** ().
        """
        ...

    def insertPlainText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#insertPlainText

        **[slot] void QPlainTextEdit::insertPlainText(const QString & text )**

        Convenience slot that inserts **text** at the current cursor position.

        It is equivalent to

        edit->textCursor().insertText(text);
        """
        ...

    def selectAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#selectAll

        **[slot] void QPlainTextEdit::selectAll()**

        Selects all text.

        **See also** **copy** (), **cut** (), and **textCursor** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#clear

        **[slot] void QPlainTextEdit::clear()**

        Deletes all the text in the text edit.

        Notes:

        * The undo/redo history is also cleared.
          * **currentCharFormat** () is
        reset, unless **textCursor** () is already at the beginning of the
        document.

        **See also** **cut** () and **setPlainText** ().
        """
        ...

    def redo(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#redo

        **[slot] void QPlainTextEdit::redo()**

        Redoes the last operation.

        If there is no operation to redo, i.e. there is no redo step in the
        undo/redo history, nothing happens.

        **See also** **undo** ().
        """
        ...

    def undo(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#undo

        **[slot] void QPlainTextEdit::undo()**

        Undoes the last operation.

        If there is no operation to undo, i.e. there is no undo step in the
        undo/redo history, nothing happens.

        **See also** **redo** ().
        """
        ...

    def paste(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#paste

        **[slot] void QPlainTextEdit::paste()**

        Pastes the text from the clipboard into the text edit at the current
        cursor position.

        If there is no text in the clipboard nothing happens.

        To change the behavior of this function, i.e. to modify what
        **QPlainTextEdit**  can paste and how it is being pasted, reimplement
        the virtual **canInsertFromMimeData** () and **insertFromMimeData** ()
        functions.

        **See also** **cut** () and **copy** ().
        """
        ...

    def copy(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#copy

        **[slot] void QPlainTextEdit::copy()**

        Copies any selected text to the clipboard.

        **See also** **copyAvailable** ().
        """
        ...

    def cut(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#cut

        **[slot] void QPlainTextEdit::cut()**

        Copies the selected text to the clipboard and deletes it from the text
        edit.

        If there is no selected text nothing happens.

        **See also** **copy** () and **paste** ().
        """
        ...

    def setPlainText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#setPlainText

        **[slot] void QPlainTextEdit::setPlainText(const QString & text )**

        Changes the text of the text edit to the string **text**. Any previous
        text is removed.

        **text** is interpreted as plain text.

        Notes:

        * The undo/redo history is also cleared.
          * **currentCharFormat** () is
        reset, unless **textCursor** () is already at the beginning of the
        document.

        **Note:** Setter function for property **plainText** .

        **See also** **toPlainText** ().
        """
        ...

    def blockCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#blockCount-prop

        **[read-only] blockCount : const int**

        This property holds the number of text blocks in the document.

        By default, in an empty document, this property contains a value of 1.

        **Access functions:**

        int **blockCount** () const
        """
        ...

    def print(self, printer: QtGui.QPagedPaintDevice) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#print

        **void QPlainTextEdit::print(QPagedPaintDevice * printer ) const**

        Convenience function to print the text edit's document to the given
        **printer**. This is equivalent to calling the print method on the
        document directly except that this function also supports
        QPrinter::Selection as print range.

        **See also** **QTextDocument::print** ().
        """
        ...

    def canPaste(self) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#canPaste

        **bool QPlainTextEdit::canPaste() const**

        Returns whether text can be pasted from the clipboard into the textedit.
        """
        ...

    def moveCursor(
        self,
        operation: QtGui.QTextCursor.MoveOperation,
        mode: QtGui.QTextCursor.MoveMode = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#moveCursor

        **void QPlainTextEdit::moveCursor(QTextCursor::MoveOperation operation ,
        QTextCursor::MoveMode mode = QTextCursor::MoveAnchor)**

        Moves the cursor by performing the given **operation**.

        If **mode** is **QTextCursor::KeepAnchor** , the cursor selects the text
        it moves over. This is the same effect that the user achieves when they
        hold down the Shift key and move the cursor with the cursor keys.

        **See also** **QTextCursor::movePosition** ().
        """
        ...

    def extraSelections(self) -> typing.List["QTextEdit.ExtraSelection"]:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#extraSelections

        **QList<QTextEdit::ExtraSelection> QPlainTextEdit::extraSelections()
        const**

        Returns previously set extra selections.

        **See also** **setExtraSelections** ().
        """
        ...

    def setExtraSelections(
        self, selections: typing.Iterable["QTextEdit.ExtraSelection"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#setExtraSelections

        **void QPlainTextEdit::setExtraSelections(const
        QList<QTextEdit::ExtraSelection> & selections )**

        This function allows temporarily marking certain regions in the document
        with a given color, specified as **selections**. This can be useful for
        example in a programming editor to mark a whole line of text with a
        given background color to indicate the existence of a breakpoint.

        **See also** **QTextEdit::ExtraSelection**  and **extraSelections** ().
        """
        ...

    def setCursorWidth(self, width: int) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#cursorWidth-prop

        **cursorWidth : int**

        This property specifies the width of the cursor in pixels. The default
        value is 1.

        **Access functions:**

        int **cursorWidth** () const
        void **setCursorWidth** (int **width** )
        """
        ...

    def cursorWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#cursorWidth-prop

        **cursorWidth : int**

        This property specifies the width of the cursor in pixels. The default
        value is 1.

        **Access functions:**

        int **cursorWidth** () const
        void **setCursorWidth** (int **width** )
        """
        ...

    def setOverwriteMode(self, overwrite: bool) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#overwriteMode-prop

        **overwriteMode : bool**

        This property holds whether text entered by the user will overwrite
        existing text

        As with many text editors, the plain text editor widget can be
        configured to insert or overwrite existing text with new text entered by
        the user.

        If this property is `true`, existing text is overwritten, character-for-
        character by new text; otherwise, text is inserted at the cursor
        position, displacing existing text.

        By default, this property is `false` (new text does not overwrite
        existing text).

        **Access functions:**

        bool **overwriteMode** () const
        void **setOverwriteMode** (bool
        **overwrite** )
        """
        ...

    def overwriteMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#overwriteMode-prop

        **overwriteMode : bool**

        This property holds whether text entered by the user will overwrite
        existing text

        As with many text editors, the plain text editor widget can be
        configured to insert or overwrite existing text with new text entered by
        the user.

        If this property is `true`, existing text is overwritten, character-for-
        character by new text; otherwise, text is inserted at the cursor
        position, displacing existing text.

        By default, this property is `false` (new text does not overwrite
        existing text).

        **Access functions:**

        bool **overwriteMode** () const
        void **setOverwriteMode** (bool
        **overwrite** )
        """
        ...

    @typing.overload
    def cursorRect(self, cursor: QtGui.QTextCursor) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#cursorRect

        **QRect QPlainTextEdit::cursorRect(const QTextCursor & cursor ) const**

        returns a rectangle (in viewport coordinates) that includes the
        **cursor**.
        """
        ...

    @typing.overload
    def cursorRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#cursorRect-1

        **QRect QPlainTextEdit::cursorRect() const**

        returns a rectangle (in viewport coordinates) that includes the cursor
        of the text edit.
        """
        ...

    def cursorForPosition(self, pos: QtCore.QPoint) -> QtGui.QTextCursor:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#cursorForPosition

        **QTextCursor QPlainTextEdit::cursorForPosition(const QPoint & pos )
        const**

        returns a **QTextCursor**  at position **pos** (in viewport
        coordinates).
        """
        ...

    @typing.overload
    def createStandardContextMenu(self) -> QMenu:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#createStandardContextMenu

        **QMenu *QPlainTextEdit::createStandardContextMenu()**

        This function creates the standard context menu which is shown when the
        user clicks on the text edit with the right mouse button. It is called
        from the default **contextMenuEvent** () handler. The popup menu's
        ownership is transferred to the caller.

        We recommend that you use the createStandardContextMenu(**QPoint** )
        version instead which will enable the actions that are sensitive to
        where the user clicked.
        """
        ...

    @typing.overload
    def createStandardContextMenu(self, position: QtCore.QPoint) -> QMenu:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#createStandardContextMenu-1

        **[since 5.5] QMenu *QPlainTextEdit::createStandardContextMenu(const
        QPoint & position )**

        This function creates the standard context menu which is shown when the
        user clicks on the text edit with the right mouse button. It is called
        from the default **contextMenuEvent** () handler and it takes the
        **position** in document coordinates where the mouse click was. This can
        enable actions that are sensitive to the position where the user
        clicked. The popup menu's ownership is transferred to the caller.

        This function was introduced in Qt 5.5.
        """
        ...

    def loadResource(self, type: int, name: QtCore.QUrl) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#loadResource

        **[virtual] QVariant QPlainTextEdit::loadResource(int type , const QUrl
        & name )**

        Loads the resource specified by the given **type** and **name**.

        This function is an extension of **QTextDocument::loadResource** ().

        **See also** **QTextDocument::loadResource** ().
        """
        ...

    def ensureCursorVisible(self) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#ensureCursorVisible

        **void QPlainTextEdit::ensureCursorVisible()**

        Ensures that the cursor is visible by scrolling the text edit if
        necessary.

        **See also** **centerCursor** () and **centerOnScroll** .
        """
        ...

    def toPlainText(self) -> str:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#toPlainText

        **QString QPlainTextEdit::toPlainText() const**

        Returns the text of the text edit as plain text.

        **Note:** Getter function for property **plainText** .

        **See also** **QPlainTextEdit::setPlainText** ().
        """
        ...

    @typing.overload
    def find(self, exp: str, options: QtGui.QTextDocument.FindFlag = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#find

        **bool QPlainTextEdit::find(const QString & exp ,
        QTextDocument::FindFlags options = QTextDocument::FindFlags())**

        Finds the next occurrence of the string, **exp** , using the given
        **options**. Returns `true` if **exp** was found and changes the cursor
        to select the match; otherwise returns `false`.
        """
        ...

    @typing.overload
    def find(
        self,
        exp: QtCore.QRegularExpression,
        options: QtGui.QTextDocument.FindFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#find-1

        **[since 5.13] bool QPlainTextEdit::find(const QRegularExpression & exp
        , QTextDocument::FindFlags options = QTextDocument::FindFlags())**

        This is an overloaded function.

        Finds the next occurrence, matching the regular expression, **exp** ,
        using the given **options**. The **QTextDocument::FindCaseSensitively**
        option is ignored for this overload, use
        **QRegularExpression::CaseInsensitiveOption**  instead.

        Returns `true` if a match was found and changes the cursor to select the
        match; otherwise returns `false`.

        This function was introduced in Qt 5.13.
        """
        ...

    def centerOnScroll(self) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#centerOnScroll-prop

        **centerOnScroll : bool**

        This property holds whether the cursor should be centered on screen

        If set to true, the plain text edit scrolls the document vertically to
        make the cursor visible at the center of the viewport. This also allows
        the text edit to scroll below the end of the document. Otherwise, if set
        to false, the plain text edit scrolls the smallest amount possible to
        ensure the cursor is visible. The same algorithm is applied to any new
        line appended through **appendPlainText** ().

        The default is false.

        **Access functions:**

        bool **centerOnScroll** () const
        void **setCenterOnScroll** (bool
        **enabled** )

        **See also** **centerCursor** () and **ensureCursorVisible** ().
        """
        ...

    def setCenterOnScroll(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#centerOnScroll-prop

        **centerOnScroll : bool**

        This property holds whether the cursor should be centered on screen

        If set to true, the plain text edit scrolls the document vertically to
        make the cursor visible at the center of the viewport. This also allows
        the text edit to scroll below the end of the document. Otherwise, if set
        to false, the plain text edit scrolls the smallest amount possible to
        ensure the cursor is visible. The same algorithm is applied to any new
        line appended through **appendPlainText** ().

        The default is false.

        **Access functions:**

        bool **centerOnScroll** () const
        void **setCenterOnScroll** (bool
        **enabled** )

        **See also** **centerCursor** () and **ensureCursorVisible** ().
        """
        ...

    def backgroundVisible(self) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#backgroundVisible-prop

        **backgroundVisible : bool**

        This property holds whether the palette background is visible outside
        the document area

        If set to true, the plain text edit paints the palette background on the
        viewport area not covered by the text document. Otherwise, if set to
        false, it won't. The feature makes it possible for the user to visually
        distinguish between the area of the document, painted with the base
        color of the palette, and the empty area not covered by any document.

        The default is false.

        **Access functions:**

        bool **backgroundVisible** () const
        void **setBackgroundVisible**
        (bool **visible** )
        """
        ...

    def setBackgroundVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#backgroundVisible-prop

        **backgroundVisible : bool**

        This property holds whether the palette background is visible outside
        the document area

        If set to true, the plain text edit paints the palette background on the
        viewport area not covered by the text document. Otherwise, if set to
        false, it won't. The feature makes it possible for the user to visually
        distinguish between the area of the document, painted with the base
        color of the palette, and the empty area not covered by any document.

        The default is false.

        **Access functions:**

        bool **backgroundVisible** () const
        void **setBackgroundVisible**
        (bool **visible** )
        """
        ...

    def setWordWrapMode(self, policy: QtGui.QTextOption.WrapMode) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#wordWrapMode-prop

        **wordWrapMode : QTextOption::WrapMode**

        This property holds the mode **QPlainTextEdit**  will use when wrapping
        text by words

        By default, this property is set to
        **QTextOption::WrapAtWordBoundaryOrAnywhere** .

        **Access functions:**

        QTextOption::WrapMode **wordWrapMode** () const
        void
        **setWordWrapMode** (QTextOption::WrapMode **policy** )

        **See also** **QTextOption::WrapMode** .

        **Member Function Documentation**
        """
        ...

    def wordWrapMode(self) -> QtGui.QTextOption.WrapMode:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#wordWrapMode-prop

        **wordWrapMode : QTextOption::WrapMode**

        This property holds the mode **QPlainTextEdit**  will use when wrapping
        text by words

        By default, this property is set to
        **QTextOption::WrapAtWordBoundaryOrAnywhere** .

        **Access functions:**

        QTextOption::WrapMode **wordWrapMode** () const
        void
        **setWordWrapMode** (QTextOption::WrapMode **policy** )

        **See also** **QTextOption::WrapMode** .

        **Member Function Documentation**
        """
        ...

    def setLineWrapMode(self, mode: "QPlainTextEdit.LineWrapMode") -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#lineWrapMode-prop

        **lineWrapMode : LineWrapMode**

        This property holds the line wrap mode

        The default mode is **WidgetWidth**  which causes words to be wrapped at
        the right edge of the text edit. Wrapping occurs at whitespace, keeping
        whole words intact. If you want wrapping to occur within words use
        **setWordWrapMode** ().

        **Access functions:**

        QPlainTextEdit::LineWrapMode **lineWrapMode** () const
        void
        **setLineWrapMode** (QPlainTextEdit::LineWrapMode **mode** )
        """
        ...

    def lineWrapMode(self) -> "QPlainTextEdit.LineWrapMode":
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#lineWrapMode-prop

        **lineWrapMode : LineWrapMode**

        This property holds the line wrap mode

        The default mode is **WidgetWidth**  which causes words to be wrapped at
        the right edge of the text edit. Wrapping occurs at whitespace, keeping
        whole words intact. If you want wrapping to occur within words use
        **setWordWrapMode** ().

        **Access functions:**

        QPlainTextEdit::LineWrapMode **lineWrapMode** () const
        void
        **setLineWrapMode** (QPlainTextEdit::LineWrapMode **mode** )
        """
        ...

    def maximumBlockCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#maximumBlockCount-prop

        **maximumBlockCount : int**

        This property holds the limit for blocks in the document.

        Specifies the maximum number of blocks the document may have. If there
        are more blocks in the document that specified with this property blocks
        are removed from the beginning of the document.

        A negative or zero value specifies that the document may contain an
        unlimited amount of blocks.

        The default value is 0.

        Note that setting this property will apply the limit immediately to the
        document contents. Setting this property also disables the undo redo
        history.

        **Access functions:**

        int **maximumBlockCount** () const
        void **setMaximumBlockCount** (int
        **maximum** )
        """
        ...

    def setMaximumBlockCount(self, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#maximumBlockCount-prop

        **maximumBlockCount : int**

        This property holds the limit for blocks in the document.

        Specifies the maximum number of blocks the document may have. If there
        are more blocks in the document that specified with this property blocks
        are removed from the beginning of the document.

        A negative or zero value specifies that the document may contain an
        unlimited amount of blocks.

        The default value is 0.

        Note that setting this property will apply the limit immediately to the
        document contents. Setting this property also disables the undo redo
        history.

        **Access functions:**

        int **maximumBlockCount** () const
        void **setMaximumBlockCount** (int
        **maximum** )
        """
        ...

    def setUndoRedoEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#undoRedoEnabled-prop

        **undoRedoEnabled : bool**

        This property holds whether undo and redo are enabled

        Users are only able to undo or redo actions if this property is true,
        and if there is an action that can be undone (or redone).

        By default, this property is `true`.

        **Access functions:**

        bool **isUndoRedoEnabled** () const
        void **setUndoRedoEnabled** (bool
        **enable** )
        """
        ...

    def isUndoRedoEnabled(self) -> bool:
        ...

    def documentTitle(self) -> str:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#documentTitle-prop

        **documentTitle : QString**

        This property holds the title of the document parsed from the text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **documentTitle** () const
        void **setDocumentTitle** (const
        QString & **title** )
        """
        ...

    def setDocumentTitle(self, title: str) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#documentTitle-prop

        **documentTitle : QString**

        This property holds the title of the document parsed from the text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **documentTitle** () const
        void **setDocumentTitle** (const
        QString & **title** )
        """
        ...

    def setTabChangesFocus(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#tabChangesFocus-prop

        **tabChangesFocus : bool**

        This property holds whether **Tab** changes focus or is accepted as
        input

        In some occasions text edits should not allow the user to input
        tabulators or change indentation using the **Tab** key, as this breaks
        the focus chain. The default is false.

        **Access functions:**

        bool **tabChangesFocus** () const
        void **setTabChangesFocus** (bool
        **b** )
        """
        ...

    def tabChangesFocus(self) -> bool:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#tabChangesFocus-prop

        **tabChangesFocus : bool**

        This property holds whether **Tab** changes focus or is accepted as
        input

        In some occasions text edits should not allow the user to input
        tabulators or change indentation using the **Tab** key, as this breaks
        the focus chain. The default is false.

        **Access functions:**

        bool **tabChangesFocus** () const
        void **setTabChangesFocus** (bool
        **b** )
        """
        ...

    def currentCharFormat(self) -> QtGui.QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#currentCharFormat

        **QTextCharFormat QPlainTextEdit::currentCharFormat() const**

        Returns the char format that is used when inserting new text.

        **See also** **setCurrentCharFormat** ().
        """
        ...

    def setCurrentCharFormat(self, format: QtGui.QTextCharFormat) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#setCurrentCharFormat

        **void QPlainTextEdit::setCurrentCharFormat(const QTextCharFormat &
        format )**

        Sets the char format that is be used when inserting new text to
        **format** by calling **QTextCursor::setCharFormat** () on the editor's
        cursor. If the editor has a selection then the char format is directly
        applied to the selection.

        **See also** **currentCharFormat** ().
        """
        ...

    def mergeCurrentCharFormat(self, modifier: QtGui.QTextCharFormat) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#mergeCurrentCharFormat

        **void QPlainTextEdit::mergeCurrentCharFormat(const QTextCharFormat &
        modifier )**

        Merges the properties specified in **modifier** into the current
        character format by calling **QTextCursor::mergeCharFormat**  on the
        editor's cursor. If the editor has a selection then the properties of
        **modifier** are directly applied to the selection.

        **See also** **QTextCursor::mergeCharFormat** ().
        """
        ...

    def textInteractionFlags(self) -> QtCore.Qt.TextInteractionFlag:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#textInteractionFlags-prop

        **textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the label should interact with user input if it displays
        text.

        If the flags contain either **Qt::LinksAccessibleByKeyboard**  or
        **Qt::TextSelectableByKeyboard**  then the focus policy is also
        automatically set to **Qt::ClickFocus** .

        The default value depends on whether the **QPlainTextEdit**  is read-
        only or editable.

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )
        """
        ...

    def setTextInteractionFlags(self, flags: QtCore.Qt.TextInteractionFlag) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#textInteractionFlags-prop

        **textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the label should interact with user input if it displays
        text.

        If the flags contain either **Qt::LinksAccessibleByKeyboard**  or
        **Qt::TextSelectableByKeyboard**  then the focus policy is also
        automatically set to **Qt::ClickFocus** .

        The default value depends on whether the **QPlainTextEdit**  is read-
        only or editable.

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )
        """
        ...

    def setReadOnly(self, ro: bool) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#readOnly-prop

        **readOnly : bool**

        This property holds whether the text edit is read-only

        In a read-only text edit the user can only navigate through the text and
        select text; modifying the text is not possible.

        This property's default is false.

        **Access functions:**

        bool **isReadOnly** () const
        void **setReadOnly** (bool **ro** )
        """
        ...

    def isReadOnly(self) -> bool:
        ...

    def textCursor(self) -> QtGui.QTextCursor:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#textCursor

        **QTextCursor QPlainTextEdit::textCursor() const**

        Returns a copy of the **QTextCursor**  that represents the currently
        visible cursor. Note that changes on the returned cursor do not affect
        **QPlainTextEdit** 's cursor; use **setTextCursor** () to update the
        visible cursor.

        **See also** **setTextCursor** ().
        """
        ...

    def setTextCursor(self, cursor: QtGui.QTextCursor) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#setTextCursor

        **void QPlainTextEdit::setTextCursor(const QTextCursor & cursor )**

        Sets the visible **cursor**.

        **See also** **textCursor** ().
        """
        ...

    def document(self) -> QtGui.QTextDocument:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#document

        **QTextDocument *QPlainTextEdit::document() const**

        Returns a pointer to the underlying document.

        **See also** **setDocument** ().
        """
        ...

    def setDocument(self, document: QtGui.QTextDocument) -> None:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#setDocument

        **void QPlainTextEdit::setDocument(QTextDocument * document )**

        Makes **document** the new document of the text editor.

        The parent **QObject**  of the provided document remains the owner of
        the object. If the current document is a child of the text editor, then
        it is deleted.

        The document must have a document layout that inherits
        **QPlainTextDocumentLayout**  (see **QTextDocument::setDocumentLayout**
        ()).

        **See also** **document** ().
        """
        ...

    @property
    def blockCountChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#blockCountChanged

        **[signal] void QPlainTextEdit::blockCountChanged(int newBlockCount )**

        This signal is emitted whenever the block count changes. The new block
        count is passed in **newBlockCount**.
        """
        ...

    @property
    def copyAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#copyAvailable

        **[signal] void QPlainTextEdit::copyAvailable(bool yes )**

        This signal is emitted when text is selected or de-selected in the text
        edit.

        When text is selected this signal will be emitted with **yes** set to
        true. If no text has been selected or if the selected text is de-
        selected this signal is emitted with **yes** set to false.

        If **yes** is true then **copy** () can be used to copy the selection to
        the clipboard. If **yes** is false then **copy** () does nothing.

        **See also** **selectionChanged** ().
        """
        ...

    @property
    def cursorPositionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#cursorPositionChanged

        **[signal] void QPlainTextEdit::cursorPositionChanged()**

        This signal is emitted whenever the position of the cursor changed.
        """
        ...

    @property
    def modificationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#modificationChanged

        **[signal] void QPlainTextEdit::modificationChanged(bool changed )**

        This signal is emitted whenever the content of the document changes in a
        way that affects the modification state. If **changed** is true, the
        document has been modified; otherwise it is false.

        For example, calling setModified(false) on a document and then inserting
        text causes the signal to get emitted. If you undo that operation,
        causing the document to return to its original unmodified state, the
        signal will get emitted again.
        """
        ...

    @property
    def redoAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#redoAvailable

        **[signal] void QPlainTextEdit::redoAvailable(bool available )**

        This signal is emitted whenever redo operations become available (
        **available** is true) or unavailable ( **available** is false).
        """
        ...

    @property
    def selectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#selectionChanged

        **[signal] void QPlainTextEdit::selectionChanged()**

        This signal is emitted whenever the selection changes.

        **See also** **copyAvailable** ().
        """
        ...

    @property
    def textChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#textChanged

        **[signal] void QPlainTextEdit::textChanged()**

        This signal is emitted whenever the document's content changes; for
        example, when text is inserted or deleted, or when formatting is
        applied.

        **Note:** Notifier signal for property **plainText** .
        """
        ...

    @property
    def undoAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#undoAvailable

        **[signal] void QPlainTextEdit::undoAvailable(bool available )**

        This signal is emitted whenever undo operations become available (
        **available** is true) or unavailable ( **available** is false).
        """
        ...

    @property
    def updateRequest(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qplaintextedit.html#updateRequest

        **[signal] void QPlainTextEdit::updateRequest(const QRect & rect , int
        dy )**

        This signal is emitted when the text document needs an update of the
        specified **rect**. If the text is scrolled, **rect** will cover the
        entire viewport area. If the text is scrolled vertically, **dy** carries
        the amount of pixels the viewport was scrolled.

        The purpose of the signal is to support extra widgets in plain text edit
        subclasses that e.g. show line numbers, breakpoints, or other extra
        information.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QMimeDatabase(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmimedatabase.html

    **Detailed Description**

    The MIME type database is provided by the freedesktop.org shared-mime-info
    project. If the MIME type database cannot be found on the system, as is the
    case on most Windows, macOS, and iOS systems, Qt will use its own copy of
    it.

    Applications which want to define custom MIME types need to install an XML
    file into the locations searched for MIME definitions. These locations can
    be queried with

    **QStandardPaths** ::locateAll(**QStandardPaths** ::GenericDataLocation,
    QLatin1String("mime/packages"),
    **QStandardPaths** ::LocateDirectory);

    On a typical Unix system, this will be /usr/share/mime/packages/, but it is
    also possible to extend the list of directories by setting the environment
    variable `XDG_DATA_DIRS`. For instance adding /opt/myapp/share to
    `XDG_DATA_DIRS` will result in /opt/myapp/share/mime/packages/ being
    searched for MIME definitions.

    Here is an example of MIME XML:

    <?xml version="1.0" encoding="UTF-8"?>
        <mime-info
    xmlns="http://www.freedesktop.org/standards/shared-mime-info">
          <mime-
    type type="application/vnd.qt.qmakeprofile">
            <comment
    xml:lang="en">Qt qmake Profile</comment>
            <glob pattern="*.pro"
    weight="50"/>
          </mime-type>
        </mime-info>

    For more details about the syntax of XML MIME definitions, including
    defining "magic" in order to detect MIME types based on data as well, read
    the Shared Mime Info specification at
    http://standards.freedesktop.org/shared-mime-info-spec/shared-mime-info-
    spec-latest.html

    On Unix systems, a binary cache is used for more performance. This cache is
    generated by the command "update-mime-database path", where path would be
    /opt/myapp/share/mime in the above example. Make sure to run this command
    when installing the MIME type definition file.

    QMimeDatabase db;
        **QMimeType**  mime = db.mimeTypeForFile(fileName);
    if (mime.inherits("text/plain")) {
            // The file is plain text, we can
    display it in a QTextEdit
        }

    **See also** **QMimeType**  and **MIME Type Browser Example** .
    """

    class MatchMode(enum.Enum):
        MatchDefault: QMimeDatabase = ...
        MatchExtension: QMimeDatabase = ...
        MatchContent: QMimeDatabase = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#QMimeDatabase-1

        **QMimeDatabase::QMimeDatabase()**

        Constructs a QMimeDatabase object.

        It is perfectly OK to create an instance of QMimeDatabase every time you
        need to perform a lookup. The parsing of mimetypes is done on demand
        (when shared-mime-info is installed) or when the very first instance is
        constructed (when parsing XML files directly).
        """
        ...

    def allMimeTypes(self) -> typing.List["QMimeType"]:
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#allMimeTypes

        **QList<QMimeType> QMimeDatabase::allMimeTypes() const**

        Returns the list of all available MIME types.

        This can be useful for showing all MIME types to the user, for instance
        in a MIME type editor. Do not use unless really necessary in other cases
        though, prefer using the **mimeTypeForXxx** () methods for performance
        reasons.
        """
        ...

    def suffixForFileName(self, fileName: str) -> str:
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#suffixForFileName

        **QString QMimeDatabase::suffixForFileName(const QString & fileName )
        const**

        Returns the suffix for the file **fileName** , as known by the MIME
        database.

        This allows to pre-select "tar.bz2" for foo.tar.bz2, but still only
        "txt" for my.file.with.dots.txt.
        """
        ...

    @typing.overload
    def mimeTypeForFileNameAndData(
        self, fileName: str, device: QIODevice
    ) -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForFileNameAndData

        **QMimeType QMimeDatabase::mimeTypeForFileNameAndData(const QString &
        fileName , QIODevice * device ) const**

        Returns a MIME type for the given **fileName** and **device** data.

        This overload can be useful when the file is remote, and we started to
        download some of its data in a device. This allows to do full MIME type
        matching for remote files as well.

        If the device is not open, it will be opened by this function, and
        closed after the MIME type detection is completed.

        A valid MIME type is always returned. If **device** data doesn't match
        any known MIME type data, the default MIME type (application/octet-
        stream) is returned.

        This method looks at both the file name and the file contents, if
        necessary. The file extension has priority over the contents, but the
        contents will be used if the file extension is unknown, or matches
        multiple MIME types.
        """
        ...

    @typing.overload
    def mimeTypeForFileNameAndData(
        self, fileName: str, data: QByteArray
    ) -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForFileNameAndData-1

        **QMimeType QMimeDatabase::mimeTypeForFileNameAndData(const QString &
        fileName , const QByteArray & data ) const**

        Returns a MIME type for the given **fileName** and device **data**.

        This overload can be useful when the file is remote, and we started to
        download some of its data. This allows to do full MIME type matching for
        remote files as well.

        A valid MIME type is always returned. If **data** doesn't match any
        known MIME type data, the default MIME type (application/octet-stream)
        is returned.

        This method looks at both the file name and the file contents, if
        necessary. The file extension has priority over the contents, but the
        contents will be used if the file extension is unknown, or matches
        multiple MIME types.
        """
        ...

    def mimeTypeForUrl(self, url: "QUrl") -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForUrl

        **QMimeType QMimeDatabase::mimeTypeForUrl(const QUrl & url ) const**

        Returns a MIME type for **url**.

        If the URL is a local file, this calls **mimeTypeForFile** .

        Otherwise the matching is done based on the file name only, except for
        schemes where file names don't mean much, like HTTP. This method always
        returns the default mimetype for HTTP URLs, use
        **QNetworkAccessManager**  to handle HTTP URLs properly.

        A valid MIME type is always returned. If **url** doesn't match any known
        MIME type data, the default MIME type (application/octet-stream) is
        returned.
        """
        ...

    @typing.overload
    def mimeTypeForData(self, data: QByteArray) -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForData

        **QMimeType QMimeDatabase::mimeTypeForData(const QByteArray & data )
        const**

        Returns a MIME type for **data**.

        A valid MIME type is always returned. If **data** doesn't match any
        known MIME type data, the default MIME type (application/octet-stream)
        is returned.
        """
        ...

    @typing.overload
    def mimeTypeForData(self, device: QIODevice) -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForData-1

        **QMimeType QMimeDatabase::mimeTypeForData(QIODevice * device ) const**

        Returns a MIME type for the data in **device**.

        A valid MIME type is always returned. If the data in **device** doesn't
        match any known MIME type data, the default MIME type
        (application/octet-stream) is returned.
        """
        ...

    def mimeTypesForFileName(self, fileName: str) -> typing.List["QMimeType"]:
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypesForFileName

        **QList<QMimeType> QMimeDatabase::mimeTypesForFileName(const QString &
        fileName ) const**

        Returns the MIME types for the file name **fileName**.

        If the file name doesn't match any known pattern, an empty list is
        returned. If multiple MIME types match this file, they are all returned.

        This function does not try to open the file. To also use the content
        when determining the MIME type, use **mimeTypeForFile** () or
        **mimeTypeForFileNameAndData** () instead.

        **See also** **mimeTypeForFile** ().
        """
        ...

    @typing.overload
    def mimeTypeForFile(
        self, fileName: str, mode: "QMimeDatabase.MatchMode" = ...
    ) -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForFile

        **QMimeType QMimeDatabase::mimeTypeForFile(const QFileInfo & fileInfo ,
        QMimeDatabase::MatchMode mode = MatchDefault) const**

        Returns a MIME type for **fileInfo**.

        A valid MIME type is always returned.

        The default matching algorithm looks at both the file name and the file
        contents, if necessary. The file extension has priority over the
        contents, but the contents will be used if the file extension is
        unknown, or matches multiple MIME types. If **fileInfo** is a Unix
        symbolic link, the file that it refers to will be used instead. If the
        file doesn't match any known pattern or data, the default MIME type
        (application/octet-stream) is returned.

        When **mode** is set to **MatchExtension** , only the file name is used,
        not the file contents. The file doesn't even have to exist. If the file
        name doesn't match any known pattern, the default MIME type
        (application/octet-stream) is returned. If multiple MIME types match
        this file, the first one (alphabetically) is returned.

        When **mode** is set to **MatchContent** , and the file is readable,
        only the file contents are used to determine the MIME type. This is
        equivalent to calling **mimeTypeForData**  with a **QFile**  as input
        device.

        **fileInfo** may refer to an absolute or relative path.

        **See also** **QMimeType::isDefault** () and **mimeTypeForData** ().
        """
        ...

    @typing.overload
    def mimeTypeForFile(
        self, fileInfo: QFileInfo, mode: "QMimeDatabase.MatchMode" = ...
    ) -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForFile-1

        **QMimeType QMimeDatabase::mimeTypeForFile(const QString & fileName ,
        QMimeDatabase::MatchMode mode = MatchDefault) const**

        Returns a MIME type for the file named **fileName** using **mode**.

        This is an overloaded function.
        """
        ...

    def mimeTypeForName(self, nameOrAlias: str) -> "QMimeType":
        """
        https://doc.qt.io/qt-6/qmimedatabase.html#mimeTypeForName

        **QMimeType QMimeDatabase::mimeTypeForName(const QString & nameOrAlias )
        const**

        Returns a MIME type for **nameOrAlias** or an invalid one if none found.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtQml import *


class QQmlPropertyValueSource(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html

    **Detailed Description**

    See **Property Value Sources**  for information on writing custom property
    value sources.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html#QQmlPropertyValueSou
        rce

        **QQmlPropertyValueSource::QQmlPropertyValueSource()**

        Constructs a QQmlPropertyValueSource.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQmlPropertyValueSource") -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html#QQmlPropertyValueSou
        rce

        **QQmlPropertyValueSource::QQmlPropertyValueSource()**

        Constructs a QQmlPropertyValueSource.
        """
        ...

    def setTarget(self, a0: QQmlProperty) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html#setTarget

        **[pure virtual] void QQmlPropertyValueSource::setTarget(const
        QQmlProperty & property )**

        Set the target **property** for the value source. This method will be
        called by the QML engine when assigning a value source.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QSizeF(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsizef.html

    **Detailed Description**

    A size is specified by a **width** () and a **height** (). It can be set in
    the constructor and changed using the **setWidth** (), **setHeight** (), or
    **scale** () functions, or using arithmetic operators. A size can also be
    manipulated directly by retrieving references to the width and height using
    the **rwidth** () and **rheight** () functions. Finally, the width and
    height can be swapped using the **transpose** () function.

    The **isValid** () function determines if a size is valid. A valid size has
    both width and height greater than or equal to zero. The **isEmpty** ()
    function returns `true` if either of the width and height is **less** than
    (or equal to) zero, while the **isNull** () function returns `true` only if
    both the width and the height is zero.

    Use the **expandedTo** () function to retrieve a size which holds the
    maximum height and width of this size and a given size. Similarly, the
    **boundedTo** () function returns a size which holds the minimum height and
    width of this size and a given size.

    The QSizeF class also provides the **toSize** () function returning a
    **QSize**  copy of this size, constructed by rounding the width and height
    to the nearest integers.

    QSizeF objects can be streamed as well as compared.

    **See also** **QSize** , **QPointF** , and **QRectF** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#QSizeF

        **QSizeF::QSizeF()**

        Constructs an invalid size.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, sz: QSize) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#QSizeF-1

        **QSizeF::QSizeF(const QSize & size )**

        Constructs a size with floating point accuracy from the given **size**.

        **See also** **toSize** ().
        """
        ...

    @typing.overload
    def __init__(self, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#QSizeF-2

        **QSizeF::QSizeF(qreal width , qreal height )**

        Constructs a size with the given finite **width** and **height**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QSizeF") -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#QSizeF

        **QSizeF::QSizeF()**

        Constructs an invalid size.

        **See also** **isValid** ().
        """
        ...

    def shrunkBy(self, m: QMarginsF) -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qsizef.html#shrunkBy

        **[since 5.14] QSizeF QSizeF::shrunkBy(QMarginsF margins ) const**

        Returns the size that results from shrinking this size by **margins**.

        This function was introduced in Qt 5.14.

        **See also** **grownBy** ().
        """
        ...

    def grownBy(self, m: QMarginsF) -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qsizef.html#grownBy

        **[since 5.14] QSizeF QSizeF::grownBy(QMarginsF margins ) const**

        Returns the size that results from growing this size by **margins**.

        This function was introduced in Qt 5.14.

        **See also** **shrunkBy** ().
        """
        ...

    def transposed(self) -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qsizef.html#transposed

        **[since 5.0] QSizeF QSizeF::transposed() const**

        Returns the size with width and height values swapped.

        This function was introduced in Qt 5.0.

        **See also** **transpose** ().
        """
        ...

    @typing.overload
    def scaled(self, s: "QSizeF", mode: Qt.AspectRatioMode) -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qsizef.html#scaled

        **[since 5.0] QSizeF QSizeF::scaled(qreal width , qreal height ,
        Qt::AspectRatioMode mode ) const**

        Returns a size scaled to a rectangle with the given **width** and
        **height** , according to the specified **mode**.

        This function was introduced in Qt 5.0.

        **See also** **scale** ().
        """
        ...

    @typing.overload
    def scaled(self, w: float, h: float, mode: Qt.AspectRatioMode) -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qsizef.html#scaled-1

        **[since 5.0] QSizeF QSizeF::scaled(const QSizeF & s ,
        Qt::AspectRatioMode mode ) const**

        This is an overloaded function.

        Returns a size scaled to a rectangle with the given size **s** ,
        according to the specified **mode**.

        This function was introduced in Qt 5.0.
        """
        ...

    def toSize(self) -> QSize:
        """
        https://doc.qt.io/qt-6/qsizef.html#toSize

        **QSize QSizeF::toSize() const**

        Returns an integer based copy of this size.

        Note that the coordinates in the returned size will be rounded to the
        nearest integer.

        **See also** **QSizeF** ().
        """
        ...

    def boundedTo(self, otherSize: "QSizeF") -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qsizef.html#boundedTo

        **QSizeF QSizeF::boundedTo(const QSizeF & otherSize ) const**

        Returns a size holding the minimum width and height of this size and the
        given **otherSize**.

        **See also** **expandedTo** () and **scale** ().
        """
        ...

    def expandedTo(self, otherSize: "QSizeF") -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qsizef.html#expandedTo

        **QSizeF QSizeF::expandedTo(const QSizeF & otherSize ) const**

        Returns a size holding the maximum width and height of this size and the
        given **otherSize**.

        **See also** **boundedTo** () and **scale** ().
        """
        ...

    def setHeight(self, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#setHeight

        **void QSizeF::setHeight(qreal height )**

        Sets the height to the given finite **height**.

        **See also** **height** (), **rheight** (), and **setWidth** ().
        """
        ...

    def setWidth(self, w: float) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#setWidth

        **void QSizeF::setWidth(qreal width )**

        Sets the width to the given finite **width**.

        **See also** **width** (), **rwidth** (), and **setHeight** ().
        """
        ...

    def height(self) -> float:
        """
        https://doc.qt.io/qt-6/qsizef.html#height

        **qreal QSizeF::height() const**

        Returns the height.

        **See also** **width** () and **setHeight** ().
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qsizef.html#width

        **qreal QSizeF::width() const**

        Returns the width.

        **See also** **height** () and **setWidth** ().
        """
        ...

    def __bool__(self) -> int:
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsizef.html#isValid

        **bool QSizeF::isValid() const**

        Returns `true` if both the width and height are equal to or greater than
        0; otherwise returns `false`.

        **See also** **isNull** () and **isEmpty** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsizef.html#isEmpty

        **bool QSizeF::isEmpty() const**

        Returns `true` if either of the width and height is less than or equal
        to 0; otherwise returns `false`.

        **See also** **isNull** () and **isValid** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsizef.html#isNull

        **bool QSizeF::isNull() const**

        Returns `true` if both the width and height are 0.0 (ignoring the sign);
        otherwise returns `false`.

        **See also** **isValid** () and **isEmpty** ().
        """
        ...

    def __repr__(self) -> str:
        ...

    @typing.overload
    def scale(self, s: "QSizeF", mode: Qt.AspectRatioMode) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#scale

        **void QSizeF::scale(qreal width , qreal height , Qt::AspectRatioMode
        mode )**

        Scales the size to a rectangle with the given **width** and **height** ,
        according to the specified **mode**.

        * If **mode** is **Qt::IgnoreAspectRatio** , the size is set to (
        **width** , **height** ).
          * If **mode** is **Qt::KeepAspectRatio** ,
        the current size is scaled to a rectangle as large as possible inside (
        **width** , **height** ), preserving the aspect ratio.
          * If **mode**
        is **Qt::KeepAspectRatioByExpanding** , the current size is scaled to a
        rectangle as small as possible outside ( **width** , **height** ),
        preserving the aspect ratio.

        Example:

        **QSizeF**  t1(10, 12);
            t1.scale(60, 60, Qt::IgnoreAspectRatio);
        // t1 is (60, 60)

            **QSizeF**  t2(10, 12);
            t2.scale(60, 60,
        Qt::KeepAspectRatio);
            // t2 is (50, 60)

            **QSizeF**  t3(10,
        12);
            t3.scale(60, 60, Qt::KeepAspectRatioByExpanding);
            // t3 is
        (60, 72)

        **See also** **setWidth** (), **setHeight** (), and **scaled** ().
        """
        ...

    @typing.overload
    def scale(self, w: float, h: float, mode: Qt.AspectRatioMode) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#scale-1

        **void QSizeF::scale(const QSizeF & size , Qt::AspectRatioMode mode )**

        This is an overloaded function.

        Scales the size to a rectangle with the given **size** , according to
        the specified **mode**.
        """
        ...

    def transpose(self) -> None:
        """
        https://doc.qt.io/qt-6/qsizef.html#transpose

        **void QSizeF::transpose()**

        Swaps the width and height values.

        **See also** **setWidth** (), **setHeight** (), and **transposed** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsRectItem(QAbstractGraphicsShapeItem):
    """
    https://doc.qt.io/qt-6/qgraphicsrectitem.html

    **Detailed Description**

    To set the item's rectangle, pass a **QRectF**  to QGraphicsRectItem's
    constructor, or call the **setRect** () function. The **rect** () function
    returns the current rectangle.

    ![](images/graphicsview-rectitem.png)

    QGraphicsRectItem uses the rectangle and the pen width to provide a
    reasonable implementation of **boundingRect** (), **shape** (), and
    **contains** (). The **paint** () function draws the rectangle using the
    item's associated pen and brush, which you can set by calling the **setPen**
    () and **setBrush** () functions.

    **Note:** The rendering of invalid rectangles, such as those with negative
    widths or heights, is undefined. If you cannot be sure that you are using
    valid rectangles (for example, if you are creating rectangles using data
    from an unreliable source) then you should use **QRectF::normalized** () to
    create normalized rectangles, and use those instead.

    **See also** **QGraphicsPathItem** , **QGraphicsEllipseItem** ,
    **QGraphicsPolygonItem** , **QGraphicsTextItem** , **QGraphicsLineItem** ,
    **QGraphicsPixmapItem** , and **Graphics View Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#QGraphicsRectItem

        **QGraphicsRectItem::QGraphicsRectItem(QGraphicsItem * parent =
        nullptr)**

        Constructs a QGraphicsRectItem. **parent** is passed to
        **QAbstractGraphicsShapeItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(
        self, rect: QtCore.QRectF, parent: typing.Optional[QGraphicsItem] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#QGraphicsRectItem-1

        **QGraphicsRectItem::QGraphicsRectItem(const QRectF & rect ,
        QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsRectItem, using **rect** as the default rectangle.
        **parent** is passed to **QAbstractGraphicsShapeItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        x: float,
        y: float,
        w: float,
        h: float,
        parent: typing.Optional[QGraphicsItem] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#QGraphicsRectItem-2

        **QGraphicsRectItem::QGraphicsRectItem(qreal x , qreal y , qreal width ,
        qreal height , QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsRectItem with a default rectangle defined by (
        **x** , **y** ) and the given **width** and **height**.

        **parent** is passed to **QAbstractGraphicsShapeItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#type

        **[override virtual] int QGraphicsRectItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsRectItem::opaqueArea()
        const**

        Reimplements: **QAbstractGraphicsShapeItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#isObscuredBy

        **[override virtual] bool QGraphicsRectItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QAbstractGraphicsShapeItem::isObscuredBy(const
        QGraphicsItem *item) const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#paint

        **[override virtual] void QGraphicsRectItem::paint(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget = nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def contains(self, point: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#contains

        **[override virtual] bool QGraphicsRectItem::contains(const QPointF &
        point ) const**

        Reimplements: **QGraphicsItem::contains(const QPointF &point) const** .
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#shape

        **[override virtual] QPainterPath QGraphicsRectItem::shape() const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#boundingRect

        **[override virtual] QRectF QGraphicsRectItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    @typing.overload
    def setRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#setRect

        **void QGraphicsRectItem::setRect(const QRectF & rectangle )**

        Sets the item's rectangle to be the given **rectangle**.

        **See also** **rect** ().
        """
        ...

    @typing.overload
    def setRect(self, ax: float, ay: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#setRect-1

        **void QGraphicsRectItem::setRect(qreal x , qreal y , qreal width ,
        qreal height )**

        Sets the item's rectangle to the rectangle defined by ( **x** , **y** )
        and the given **width** and **height**.

        This convenience function is equivalent to calling `setRect(QRectF(x, y,
        width, height))`

        **See also** **rect** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsrectitem.html#rect

        **QRectF QGraphicsRectItem::rect() const**

        Returns the item's rectangle.

        **See also** **setRect** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QCborError(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcborerror.html

    **Detailed Description**

    **See also** **QCborStreamReader** , **QCborValue** , and
    **QCborParserError** .
    """

    class Code(enum.Enum):
        UnknownError: QCborError = ...
        AdvancePastEnd: QCborError = ...
        InputOutputError: QCborError = ...
        GarbageAtEnd: QCborError = ...
        EndOfFile: QCborError = ...
        UnexpectedBreak: QCborError = ...
        UnknownType: QCborError = ...
        IllegalType: QCborError = ...
        IllegalNumber: QCborError = ...
        IllegalSimpleType: QCborError = ...
        InvalidUtf8String: QCborError = ...
        DataTooLarge: QCborError = ...
        NestingTooDeep: QCborError = ...
        UnsupportedType: QCborError = ...
        NoError: QCborError = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QCborError") -> None:
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qcborerror.html#toString

        **QString QCborError::toString() const**

        Returns a text string that matches the error code in this **QCborError**
        object.

        Note: the string is not translated. Applications whose interface allow
        users to parse CBOR streams need to provide their own, translated
        strings.

        **See also** **QCborError::Code** .
        """
        ...

    def code(self) -> "QCborError.Code":
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsEllipseItem(QAbstractGraphicsShapeItem):
    """
    https://doc.qt.io/qt-6/qgraphicsellipseitem.html

    **Detailed Description**

    QGraphicsEllipseItem respresents an ellipse with a fill and an outline, and
    you can also use it for ellipse segments (see **startAngle** (),
    **spanAngle** ()).

    ![](images/graphicsview-ellipseitem.png)![](images/graphicsview-ellipseitem-
    pie.png)

    To set the item's ellipse, pass a **QRectF**  to QGraphicsEllipseItem's
    constructor, or call **setRect** (). The **rect** () function returns the
    current ellipse geometry.

    QGraphicsEllipseItem uses the rect and the pen width to provide a reasonable
    implementation of **boundingRect** (), **shape** (), and **contains** ().
    The **paint** () function draws the ellipse using the item's associated pen
    and brush, which you can set by calling **setPen** () and **setBrush** ().

    **See also** **QGraphicsPathItem** , **QGraphicsRectItem** ,
    **QGraphicsPolygonItem** , **QGraphicsTextItem** , **QGraphicsLineItem** ,
    **QGraphicsPixmapItem** , and **Graphics View Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#QGraphicsEllipseItem

        **QGraphicsEllipseItem::QGraphicsEllipseItem(QGraphicsItem * parent =
        nullptr)**

        Constructs a QGraphicsEllipseItem. **parent** is passed to
        **QAbstractGraphicsShapeItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(
        self, rect: QtCore.QRectF, parent: typing.Optional[QGraphicsItem] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#QGraphicsEllipseItem-1

        **QGraphicsEllipseItem::QGraphicsEllipseItem(const QRectF & rect ,
        QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsEllipseItem using **rect** as the default
        rectangle. **parent** is passed to **QAbstractGraphicsShapeItem** 's
        constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        x: float,
        y: float,
        w: float,
        h: float,
        parent: typing.Optional[QGraphicsItem] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#QGraphicsEllipseItem-2

        **QGraphicsEllipseItem::QGraphicsEllipseItem(qreal x , qreal y , qreal
        width , qreal height , QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsEllipseItem using the rectangle defined by ( **x**
        , **y** ) and the given **width** and **height** , as the default
        rectangle. **parent** is passed to **QAbstractGraphicsShapeItem** 's
        constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#type

        **[override virtual] int QGraphicsEllipseItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsEllipseItem::opaqueArea()
        const**

        Reimplements: **QAbstractGraphicsShapeItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#isObscuredBy

        **[override virtual] bool QGraphicsEllipseItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QAbstractGraphicsShapeItem::isObscuredBy(const
        QGraphicsItem *item) const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#paint

        **[override virtual] void QGraphicsEllipseItem::paint(QPainter * painter
        , const QStyleOptionGraphicsItem * option , QWidget * widget =
        nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def contains(self, point: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#contains

        **[override virtual] bool QGraphicsEllipseItem::contains(const QPointF &
        point ) const**

        Reimplements: **QGraphicsItem::contains(const QPointF &point) const** .
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#shape

        **[override virtual] QPainterPath QGraphicsEllipseItem::shape() const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#boundingRect

        **[override virtual] QRectF QGraphicsEllipseItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    def setSpanAngle(self, angle: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#setSpanAngle

        **void QGraphicsEllipseItem::setSpanAngle(int angle )**

        Sets the span angle for an ellipse segment to **angle** , which is in
        16ths of a degree. This angle is used together with **startAngle** () to
        represent an ellipse segment (a pie). By default, the span angle is 5760
        (360 * 16, a full ellipse).

        **See also** **spanAngle** (), **setStartAngle** (), and
        **QPainter::drawPie** ().
        """
        ...

    def spanAngle(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#spanAngle

        **int QGraphicsEllipseItem::spanAngle() const**

        Returns the span angle of an ellipse segment in 16ths of a degree. This
        angle is used together with **startAngle** () for representing an
        ellipse segment (a pie). By default, this function returns 5760 (360 *
        16, a full ellipse).

        **See also** **setSpanAngle** () and **startAngle** ().
        """
        ...

    def setStartAngle(self, angle: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#setStartAngle

        **void QGraphicsEllipseItem::setStartAngle(int angle )**

        Sets the start angle for an ellipse segment to **angle** , which is in
        16ths of a degree. This angle is used together with **spanAngle** () for
        representing an ellipse segment (a pie). By default, the start angle is
        0.

        **See also** **startAngle** (), **setSpanAngle** (), and
        **QPainter::drawPie** ().
        """
        ...

    def startAngle(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#startAngle

        **int QGraphicsEllipseItem::startAngle() const**

        Returns the start angle for an ellipse segment in 16ths of a degree.
        This angle is used together with **spanAngle** () for representing an
        ellipse segment (a pie). By default, the start angle is 0.

        **See also** **setStartAngle** () and **spanAngle** ().
        """
        ...

    @typing.overload
    def setRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#setRect

        **void QGraphicsEllipseItem::setRect(const QRectF & rect )**

        Sets the item's ellipse geometry to **rect**. The rectangle's left edge
        defines the left edge of the ellipse, and the rectangle's top edge
        describes the top of the ellipse. The height and width of the rectangle
        describe the height and width of the ellipse.

        **See also** **rect** () and **QPainter::drawEllipse** ().
        """
        ...

    @typing.overload
    def setRect(self, ax: float, ay: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#setRect-1

        **void QGraphicsEllipseItem::setRect(qreal x , qreal y , qreal width ,
        qreal height )**

        Sets the item's rectangle to the rectangle defined by ( **x** , **y** )
        and the given **width** and **height**.

        This convenience function is equivalent to calling `setRect(QRectF(x, y,
        width, height))`

        **See also** **rect** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsellipseitem.html#rect

        **QRectF QGraphicsEllipseItem::rect() const**

        Returns the item's ellipse geometry as a **QRectF** .

        **See also** **setRect** () and **QPainter::drawEllipse** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QBluetoothUuid(QtCore.QUuid):
    """
    https://doc.qt.io/qt-6/qbluetoothuuid.html

    **Detailed Description**
    """

    class DescriptorType(enum.Enum):
        UnknownDescriptorType: QBluetoothUuid = ...
        CharacteristicExtendedProperties: QBluetoothUuid = ...
        CharacteristicUserDescription: QBluetoothUuid = ...
        ClientCharacteristicConfiguration: QBluetoothUuid = ...
        ServerCharacteristicConfiguration: QBluetoothUuid = ...
        CharacteristicPresentationFormat: QBluetoothUuid = ...
        CharacteristicAggregateFormat: QBluetoothUuid = ...
        ValidRange: QBluetoothUuid = ...
        ExternalReportReference: QBluetoothUuid = ...
        ReportReference: QBluetoothUuid = ...
        EnvironmentalSensingConfiguration: QBluetoothUuid = ...
        EnvironmentalSensingMeasurement: QBluetoothUuid = ...
        EnvironmentalSensingTriggerSetting: QBluetoothUuid = ...

    class CharacteristicType(enum.Enum):
        DeviceName: QBluetoothUuid = ...
        Appearance: QBluetoothUuid = ...
        PeripheralPrivacyFlag: QBluetoothUuid = ...
        ReconnectionAddress: QBluetoothUuid = ...
        PeripheralPreferredConnectionParameters: QBluetoothUuid = ...
        ServiceChanged: QBluetoothUuid = ...
        AlertLevel: QBluetoothUuid = ...
        TxPowerLevel: QBluetoothUuid = ...
        DateTime: QBluetoothUuid = ...
        DayOfWeek: QBluetoothUuid = ...
        DayDateTime: QBluetoothUuid = ...
        ExactTime256: QBluetoothUuid = ...
        DSTOffset: QBluetoothUuid = ...
        TimeZone: QBluetoothUuid = ...
        LocalTimeInformation: QBluetoothUuid = ...
        TimeWithDST: QBluetoothUuid = ...
        TimeAccuracy: QBluetoothUuid = ...
        TimeSource: QBluetoothUuid = ...
        ReferenceTimeInformation: QBluetoothUuid = ...
        TimeUpdateControlPoint: QBluetoothUuid = ...
        TimeUpdateState: QBluetoothUuid = ...
        GlucoseMeasurement: QBluetoothUuid = ...
        BatteryLevel: QBluetoothUuid = ...
        TemperatureMeasurement: QBluetoothUuid = ...
        TemperatureType: QBluetoothUuid = ...
        IntermediateTemperature: QBluetoothUuid = ...
        MeasurementInterval: QBluetoothUuid = ...
        BootKeyboardInputReport: QBluetoothUuid = ...
        SystemID: QBluetoothUuid = ...
        ModelNumberString: QBluetoothUuid = ...
        SerialNumberString: QBluetoothUuid = ...
        FirmwareRevisionString: QBluetoothUuid = ...
        HardwareRevisionString: QBluetoothUuid = ...
        SoftwareRevisionString: QBluetoothUuid = ...
        ManufacturerNameString: QBluetoothUuid = ...
        IEEE1107320601RegulatoryCertificationDataList: QBluetoothUuid = ...
        CurrentTime: QBluetoothUuid = ...
        MagneticDeclination: QBluetoothUuid = ...
        ScanRefresh: QBluetoothUuid = ...
        BootKeyboardOutputReport: QBluetoothUuid = ...
        BootMouseInputReport: QBluetoothUuid = ...
        GlucoseMeasurementContext: QBluetoothUuid = ...
        BloodPressureMeasurement: QBluetoothUuid = ...
        IntermediateCuffPressure: QBluetoothUuid = ...
        HeartRateMeasurement: QBluetoothUuid = ...
        BodySensorLocation: QBluetoothUuid = ...
        HeartRateControlPoint: QBluetoothUuid = ...
        AlertStatus: QBluetoothUuid = ...
        RingerControlPoint: QBluetoothUuid = ...
        RingerSetting: QBluetoothUuid = ...
        AlertCategoryIDBitMask: QBluetoothUuid = ...
        AlertCategoryID: QBluetoothUuid = ...
        AlertNotificationControlPoint: QBluetoothUuid = ...
        UnreadAlertStatus: QBluetoothUuid = ...
        NewAlert: QBluetoothUuid = ...
        SupportedNewAlertCategory: QBluetoothUuid = ...
        SupportedUnreadAlertCategory: QBluetoothUuid = ...
        BloodPressureFeature: QBluetoothUuid = ...
        HIDInformation: QBluetoothUuid = ...
        ReportMap: QBluetoothUuid = ...
        HIDControlPoint: QBluetoothUuid = ...
        Report: QBluetoothUuid = ...
        ProtocolMode: QBluetoothUuid = ...
        ScanIntervalWindow: QBluetoothUuid = ...
        PnPID: QBluetoothUuid = ...
        GlucoseFeature: QBluetoothUuid = ...
        RecordAccessControlPoint: QBluetoothUuid = ...
        RSCMeasurement: QBluetoothUuid = ...
        RSCFeature: QBluetoothUuid = ...
        SCControlPoint: QBluetoothUuid = ...
        CSCMeasurement: QBluetoothUuid = ...
        CSCFeature: QBluetoothUuid = ...
        SensorLocation: QBluetoothUuid = ...
        CyclingPowerMeasurement: QBluetoothUuid = ...
        CyclingPowerVector: QBluetoothUuid = ...
        CyclingPowerFeature: QBluetoothUuid = ...
        CyclingPowerControlPoint: QBluetoothUuid = ...
        LocationAndSpeed: QBluetoothUuid = ...
        Navigation: QBluetoothUuid = ...
        PositionQuality: QBluetoothUuid = ...
        LNFeature: QBluetoothUuid = ...
        LNControlPoint: QBluetoothUuid = ...
        Elevation: QBluetoothUuid = ...
        Pressure: QBluetoothUuid = ...
        Temperature: QBluetoothUuid = ...
        Humidity: QBluetoothUuid = ...
        TrueWindSpeed: QBluetoothUuid = ...
        TrueWindDirection: QBluetoothUuid = ...
        ApparentWindSpeed: QBluetoothUuid = ...
        ApparentWindDirection: QBluetoothUuid = ...
        GustFactor: QBluetoothUuid = ...
        PollenConcentration: QBluetoothUuid = ...
        UVIndex: QBluetoothUuid = ...
        Irradiance: QBluetoothUuid = ...
        Rainfall: QBluetoothUuid = ...
        WindChill: QBluetoothUuid = ...
        HeatIndex: QBluetoothUuid = ...
        DewPoint: QBluetoothUuid = ...
        DescriptorValueChanged: QBluetoothUuid = ...
        AerobicHeartRateLowerLimit: QBluetoothUuid = ...
        AerobicThreshold: QBluetoothUuid = ...
        Age: QBluetoothUuid = ...
        AnaerobicHeartRateLowerLimit: QBluetoothUuid = ...
        AnaerobicHeartRateUpperLimit: QBluetoothUuid = ...
        AnaerobicThreshold: QBluetoothUuid = ...
        AerobicHeartRateUpperLimit: QBluetoothUuid = ...
        DateOfBirth: QBluetoothUuid = ...
        DateOfThresholdAssessment: QBluetoothUuid = ...
        EmailAddress: QBluetoothUuid = ...
        FatBurnHeartRateLowerLimit: QBluetoothUuid = ...
        FatBurnHeartRateUpperLimit: QBluetoothUuid = ...
        FirstName: QBluetoothUuid = ...
        FiveZoneHeartRateLimits: QBluetoothUuid = ...
        Gender: QBluetoothUuid = ...
        HeartRateMax: QBluetoothUuid = ...
        Height: QBluetoothUuid = ...
        HipCircumference: QBluetoothUuid = ...
        LastName: QBluetoothUuid = ...
        MaximumRecommendedHeartRate: QBluetoothUuid = ...
        RestingHeartRate: QBluetoothUuid = ...
        SportTypeForAerobicAnaerobicThresholds: QBluetoothUuid = ...
        ThreeZoneHeartRateLimits: QBluetoothUuid = ...
        TwoZoneHeartRateLimits: QBluetoothUuid = ...
        VO2Max: QBluetoothUuid = ...
        WaistCircumference: QBluetoothUuid = ...
        Weight: QBluetoothUuid = ...
        DatabaseChangeIncrement: QBluetoothUuid = ...
        UserIndex: QBluetoothUuid = ...
        BodyCompositionFeature: QBluetoothUuid = ...
        BodyCompositionMeasurement: QBluetoothUuid = ...
        WeightMeasurement: QBluetoothUuid = ...
        WeightScaleFeature: QBluetoothUuid = ...
        UserControlPoint: QBluetoothUuid = ...
        MagneticFluxDensity2D: QBluetoothUuid = ...
        MagneticFluxDensity3D: QBluetoothUuid = ...
        Language: QBluetoothUuid = ...
        BarometricPressureTrend: QBluetoothUuid = ...

    class ServiceClassUuid(enum.Enum):
        ServiceDiscoveryServer: QBluetoothUuid = ...
        BrowseGroupDescriptor: QBluetoothUuid = ...
        PublicBrowseGroup: QBluetoothUuid = ...
        SerialPort: QBluetoothUuid = ...
        LANAccessUsingPPP: QBluetoothUuid = ...
        DialupNetworking: QBluetoothUuid = ...
        IrMCSync: QBluetoothUuid = ...
        ObexObjectPush: QBluetoothUuid = ...
        OBEXFileTransfer: QBluetoothUuid = ...
        IrMCSyncCommand: QBluetoothUuid = ...
        Headset: QBluetoothUuid = ...
        AudioSource: QBluetoothUuid = ...
        AudioSink: QBluetoothUuid = ...
        AV_RemoteControlTarget: QBluetoothUuid = ...
        AdvancedAudioDistribution: QBluetoothUuid = ...
        AV_RemoteControl: QBluetoothUuid = ...
        AV_RemoteControlController: QBluetoothUuid = ...
        HeadsetAG: QBluetoothUuid = ...
        PANU: QBluetoothUuid = ...
        NAP: QBluetoothUuid = ...
        GN: QBluetoothUuid = ...
        DirectPrinting: QBluetoothUuid = ...
        ReferencePrinting: QBluetoothUuid = ...
        BasicImage: QBluetoothUuid = ...
        ImagingResponder: QBluetoothUuid = ...
        ImagingAutomaticArchive: QBluetoothUuid = ...
        ImagingReferenceObjects: QBluetoothUuid = ...
        Handsfree: QBluetoothUuid = ...
        HandsfreeAudioGateway: QBluetoothUuid = ...
        DirectPrintingReferenceObjectsService: QBluetoothUuid = ...
        ReflectedUI: QBluetoothUuid = ...
        BasicPrinting: QBluetoothUuid = ...
        PrintingStatus: QBluetoothUuid = ...
        HumanInterfaceDeviceService: QBluetoothUuid = ...
        HardcopyCableReplacement: QBluetoothUuid = ...
        HCRPrint: QBluetoothUuid = ...
        HCRScan: QBluetoothUuid = ...
        SIMAccess: QBluetoothUuid = ...
        PhonebookAccessPCE: QBluetoothUuid = ...
        PhonebookAccessPSE: QBluetoothUuid = ...
        PhonebookAccess: QBluetoothUuid = ...
        HeadsetHS: QBluetoothUuid = ...
        MessageAccessServer: QBluetoothUuid = ...
        MessageNotificationServer: QBluetoothUuid = ...
        MessageAccessProfile: QBluetoothUuid = ...
        GNSS: QBluetoothUuid = ...
        GNSSServer: QBluetoothUuid = ...
        Display3D: QBluetoothUuid = ...
        Glasses3D: QBluetoothUuid = ...
        Synchronization3D: QBluetoothUuid = ...
        MPSProfile: QBluetoothUuid = ...
        MPSService: QBluetoothUuid = ...
        PnPInformation: QBluetoothUuid = ...
        GenericNetworking: QBluetoothUuid = ...
        GenericFileTransfer: QBluetoothUuid = ...
        GenericAudio: QBluetoothUuid = ...
        GenericTelephony: QBluetoothUuid = ...
        VideoSource: QBluetoothUuid = ...
        VideoSink: QBluetoothUuid = ...
        VideoDistribution: QBluetoothUuid = ...
        HDP: QBluetoothUuid = ...
        HDPSource: QBluetoothUuid = ...
        HDPSink: QBluetoothUuid = ...
        GenericAccess: QBluetoothUuid = ...
        GenericAttribute: QBluetoothUuid = ...
        ImmediateAlert: QBluetoothUuid = ...
        LinkLoss: QBluetoothUuid = ...
        TxPower: QBluetoothUuid = ...
        CurrentTimeService: QBluetoothUuid = ...
        ReferenceTimeUpdateService: QBluetoothUuid = ...
        NextDSTChangeService: QBluetoothUuid = ...
        Glucose: QBluetoothUuid = ...
        HealthThermometer: QBluetoothUuid = ...
        DeviceInformation: QBluetoothUuid = ...
        HeartRate: QBluetoothUuid = ...
        PhoneAlertStatusService: QBluetoothUuid = ...
        BatteryService: QBluetoothUuid = ...
        BloodPressure: QBluetoothUuid = ...
        AlertNotificationService: QBluetoothUuid = ...
        HumanInterfaceDevice: QBluetoothUuid = ...
        ScanParameters: QBluetoothUuid = ...
        RunningSpeedAndCadence: QBluetoothUuid = ...
        CyclingSpeedAndCadence: QBluetoothUuid = ...
        CyclingPower: QBluetoothUuid = ...
        LocationAndNavigation: QBluetoothUuid = ...
        EnvironmentalSensing: QBluetoothUuid = ...
        BodyComposition: QBluetoothUuid = ...
        UserData: QBluetoothUuid = ...
        WeightScale: QBluetoothUuid = ...
        BondManagement: QBluetoothUuid = ...
        ContinuousGlucoseMonitoring: QBluetoothUuid = ...

    class ProtocolUuid(enum.Enum):
        Sdp: QBluetoothUuid = ...
        Udp: QBluetoothUuid = ...
        Rfcomm: QBluetoothUuid = ...
        Tcp: QBluetoothUuid = ...
        TcsBin: QBluetoothUuid = ...
        TcsAt: QBluetoothUuid = ...
        Att: QBluetoothUuid = ...
        Obex: QBluetoothUuid = ...
        Ip: QBluetoothUuid = ...
        Ftp: QBluetoothUuid = ...
        Http: QBluetoothUuid = ...
        Wsp: QBluetoothUuid = ...
        Bnep: QBluetoothUuid = ...
        Upnp: QBluetoothUuid = ...
        Hidp: QBluetoothUuid = ...
        HardcopyControlChannel: QBluetoothUuid = ...
        HardcopyDataChannel: QBluetoothUuid = ...
        HardcopyNotification: QBluetoothUuid = ...
        Avctp: QBluetoothUuid = ...
        Avdtp: QBluetoothUuid = ...
        Cmtp: QBluetoothUuid = ...
        UdiCPlain: QBluetoothUuid = ...
        McapControlChannel: QBluetoothUuid = ...
        McapDataChannel: QBluetoothUuid = ...
        L2cap: QBluetoothUuid = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid

        **QBluetoothUuid::QBluetoothUuid()**

        Constructs a new null Bluetooth UUID.
        """
        ...

    @typing.overload
    def __init__(self, uuid: "QBluetoothUuid.ProtocolUuid") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-1

        **QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::ProtocolUuid uuid )**

        Constructs a new Bluetooth UUID from the protocol **uuid**.
        """
        ...

    @typing.overload
    def __init__(self, uuid: "QBluetoothUuid.ServiceClassUuid") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-2

        **QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::ServiceClassUuid uuid
        )**

        Constructs a new Bluetooth UUID from the service class **uuid**.
        """
        ...

    @typing.overload
    def __init__(self, uuid: "QBluetoothUuid.CharacteristicType") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-3

        **[since 5.4]
        QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::CharacteristicType uuid
        )**

        Constructs a new Bluetooth UUID from the characteristic type **uuid**.

        This function was introduced in Qt 5.4.
        """
        ...

    @typing.overload
    def __init__(self, uuid: "QBluetoothUuid.DescriptorType") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-4

        **[since 5.4]
        QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::DescriptorType uuid )**

        Constructs a new Bluetooth UUID from the descriptor type **uuid**.

        This function was introduced in Qt 5.4.
        """
        ...

    @typing.overload
    def __init__(self, uuid: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-5

        **QBluetoothUuid::QBluetoothUuid(quint16 uuid )**

        Constructs a new Bluetooth UUID from the 16 bit **uuid**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        uuid: typing.Tuple[
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-6

        **QBluetoothUuid::QBluetoothUuid(quint32 uuid )**

        Constructs a new Bluetooth UUID from the 32 bit **uuid**.
        """
        ...

    @typing.overload
    def __init__(self, uuid: str) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-7

        **QBluetoothUuid::QBluetoothUuid(quint128 uuid )**

        Constructs a new Bluetooth UUID from the 128 bit **uuid**.

        Note that **uuid** must be in big endian order.
        """
        ...

    @typing.overload
    def __init__(self, uuid: "QBluetoothUuid") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-8

        **QBluetoothUuid::QBluetoothUuid(const QString & uuid )**

        Creates a QBluetoothUuid object from the string **uuid** , which must be
        formatted as five hex fields separated by '-', e.g., "{xxxxxxxx-xxxx-
        xxxx-xxxx-xxxxxxxxxxxx}" where 'x' is a hex digit. The curly braces
        shown here are optional, but it is normal to include them. If the
        conversion fails, a null UUID is created. See **QUuid::toString** () for
        an explanation of how the five hex fields map to the public data members
        in **QUuid** .
        """
        ...

    @typing.overload
    def __init__(self, uuid: QtCore.QUuid) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#QBluetoothUuid-10

        **QBluetoothUuid::QBluetoothUuid(const QUuid & uuid )**

        Constructs a new Bluetooth UUID that is a copy of **uuid**.
        """
        ...

    @staticmethod
    def descriptorToString(uuid: "QBluetoothUuid.DescriptorType") -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#descriptorToString

        **[static, since 5.4] QString
        QBluetoothUuid::descriptorToString(QBluetoothUuid::DescriptorType uuid
        )**

        Returns a human-readable and translated name for the given descriptor
        type represented by **uuid**.

        This function was introduced in Qt 5.4.

        **See also** **QBluetoothUuid::DescriptorType** .
        """
        ...

    @staticmethod
    def characteristicToString(uuid: "QBluetoothUuid.CharacteristicType") -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#characteristicToString

        **[static, since 5.4] QString QBluetoothUuid::characteristicToString(QBl
        uetoothUuid::CharacteristicType uuid )**

        Returns a human-readable and translated name for the given
        characteristic type represented by **uuid**.

        This function was introduced in Qt 5.4.

        **See also** **QBluetoothUuid::CharacteristicType** .
        """
        ...

    @staticmethod
    def protocolToString(uuid: "QBluetoothUuid.ProtocolUuid") -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#protocolToString

        **[static, since 5.4] QString
        QBluetoothUuid::protocolToString(QBluetoothUuid::ProtocolUuid uuid )**

        Returns a human-readable and translated name for the given protocol
        represented by **uuid**.

        This function was introduced in Qt 5.4.

        **See also** **QBluetoothUuid::ProtocolUuid** .
        """
        ...

    @staticmethod
    def serviceClassToString(uuid: "QBluetoothUuid.ServiceClassUuid") -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#serviceClassToString

        **[static, since Qt 5.4] QString
        QBluetoothUuid::serviceClassToString(QBluetoothUuid::ServiceClassUuid
        uuid )**

        Returns a human-readable and translated name for the given service class
        represented by **uuid**.

        This function was introduced in Qt 5.4.

        **See also** **QBluetoothUuid::ServiceClassUuid** .
        """
        ...

    def toUInt128(
        self,
    ) -> typing.Tuple[
        int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int
    ]:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#toUInt128

        **quint128 QBluetoothUuid::toUInt128() const**

        Returns the 128 bit representation of this UUID.
        """
        ...

    def toUInt32(self) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#toUInt32

        **quint32 QBluetoothUuid::toUInt32(bool * ok = nullptr) const**

        Returns the 32 bit representation of this UUID. If **ok** is passed, it
        is set to true if the conversion is possible, otherwise it is set to
        false. The return value is undefined if **ok** is set to false.
        """
        ...

    def toUInt16(self) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#toUInt16

        **quint16 QBluetoothUuid::toUInt16(bool * ok = nullptr) const**

        Returns the 16 bit representation of this UUID. If **ok** is passed, it
        is set to true if the conversion is possible, otherwise it is set to
        false. The return value is undefined if **ok** is set to false.
        """
        ...

    def minimumSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothuuid.html#minimumSize

        **int QBluetoothUuid::minimumSize() const**

        Returns the minimum size in bytes that this UUID can be represented in.
        For non-null UUIDs 2, 4 or 16 is returned. 0 is returned for null UUIDs.

        **See also** **isNull** (), **toUInt16** (), **toUInt32** (), and
        **toUInt128** ().
        """
        ...
